import os
import sys
sys.path.append('../..')
from abc import abstractmethod, ABCMeta
from .htmlclass import *
from .firefox import firefox
#import test
from lxml import etree#need install
import re
import pprint
from urllib.parse import urljoin
import inspect

import secrets

class Jav321(getVideoInfoBase):
    __metaclass__ = ABCMeta

    def __init__(self):
        super().__init__()

    def getTitle(self,html) -> str:
        res =  html.xpath("/html/body/div[2]/div[1]/div[1]/div[1]/h3/text()")
        if res:
            return res[0].strip()
        return ''

    def parseInfo(self,html):
        elements = html.xpath('//div[@class="row"]/div[@class="col-md-9"]')
        element_html = etree.tostring(elements[0],encoding="unicode")
        str = re.sub("<br/>","\n",element_html)
        str = re.sub("<.*?>","",str)
        info = dict()
        for line in str.splitlines():
            #print(line)
            data = line.split(": ")
            info[data[0]]=data[1]
        return(info)

    def getTrailer(self,html) -> str:
        videourlPather = re.compile(r'<source src=\"(.*?)\"')
        videourl = videourlPather.findall(html)
        if videourl:
            url = videourl[0].replace('awscc3001.r18.com', 'cc3001.dmm.co.jp').replace('cc3001.r18.com', 'cc3001.dmm.co.jp')
            return url
        else:
            return ''

    def getExtrafanart(self,html):  # 获取剧照
        elements = html.xpath('//div[@class="col-md-3"]/div[@class="col-xs-12 col-md-12"]')
        imgs = []
        if elements:
            for element in elements:
                for a in element.findall(".//img[@class='img-responsive']"):
                    imgs.append(a.attrib["src"])
        if not imgs:
            return ''
        return imgs
    def getCover(self,html):
        return html.xpath("/html/body/div[2]/div[2]/div[1]/p/a/img/@src")[0]
    def getOutline(self,html):
        return html.xpath("/html/body/div[2]/div[1]/div[1]/div[2]/div[3]/div/text()")[0]
    def getSeries2(self,html):
        return html.xpath("/html/body/div[2]/div[1]/div[1]/div[2]/div[1]/div[2]/a[11]/text()")[0]
    def getActor(self,html):
        data = self.parseInfo(html)
        if "出演者" in data:
            return data["出演者"]
        else:
            return ""
    def getLabel(self,html):
        data = self.parseInfo(html)
        if "メーカー" in data:
            return data["メーカー"]
        else:
            return ""
    def getTag(self,html):
        data = self.parseInfo(html)
        if "ジャンル" in data:
            return data["ジャンル"]
        else:
            return ""
    def getStudio(self,html):
        data = self.parseInfo(html)
        if "メーカー" in data:
            return data["メーカー"]
        else:
            return ""
    def getNum(self,html):
        data = self.parseInfo(html)
        if "品番" in data:
            return data["品番"]
        else:
            return ""
    def getRelease(self,html):
        data = self.parseInfo(html)
        if "配信開始日" in data:
            return data["配信開始日"]
        else:
            return ""
    def getRuntime(self,html):
        data = self.parseInfo(html)
        if "収録時間" in data:
            return data["収録時間"]
        else:
            return ""
    def getYear(self,html):
        data = self.parseInfo(html)
        if "release" in data:
            return data["release"][:4]
        else:
            return ""
    def getSeries(self,html):
        data = self.parseInfo(html)
        if "シリーズ" in data:
            return data["シリーズ"]
        else:
            return ""
    def getWebsite(self,html):
        element_html = etree.tostring(html,encoding="unicode")
        web = re.compile("this.page.url = (.*);")
        webline = web.findall(element_html)
        if webline:
            webline = webline[0]
        if not webline:
            return ''
        return webline
    def getMagnetLink(self,html):
        elements = html.xpath('//table[@class="table table-striped"]/tr')
        video_lists = []
        for element in elements:
            #print(etree.tostring(element))
            info = VideoDownloadInfo()
            a = element.findall("./td/a")
            if a:
                info["magnetlink"] = a[0].attrib["href"]
                #print(element.attrib['onclick'])
                for text in element.itertext():
                    if re.findall("GB",text):
                        info["size"] = re.findall(".+GB",text)[0]
                        video_lists.append(info)

        if not video_lists:
            return ""
        else:
            # video_lists = sorted(video_lists,key = lambda i:(i["isChn"],i["isHD"],i["date"],i["size"]),reverse=True)
            video_lists = video_lists
        return video_lists
    def main(self,number):
        self.fx = firefox()
        htmlcode = self.fx.post_html(url="https://www.jav321.com/search", data={"sn": number})
        #print(htmlcode)
        self.lx = etree.fromstring(htmlcode,etree.HTMLParser())
        self.getVideoInfo(self.lx)
        self.info['website'] = self.getWebsite(self.lx)
        self.info['source'] = self.getWebsite(self.lx)
        htmlcode = self.fx.post_html(url="https://www.jav321.com/emule", data={"sn": number})
        return self.info


if __name__ == "__main__":
    jav = Jav321()
    #print(jav.main("jul-404"))
    #print(jav.main( "FC2-2125351"))



import os
import sys
sys.path.append('../..')
from abc import abstractmethod, ABCMeta
from .htmlclass import *
from .firefox import firefox
#import test
from lxml import etree#need install
import re
import pprint
from urllib.parse import urljoin
import inspect
import secrets
import json


# import io
# sys.stdout = io.TextIOWrapper(sys.stdout.buffer, errors = 'replace', line_buffering = True)


class Avsox(getVideoInfoBase):
    __metaclass__ = ABCMeta
    
    def __init__(self):
        super().__init__()

    def getMagnetLink(self,html):
        return ''
    def getActorPhoto(self,html):
        a = html.xpath('//a[@class="avatar-box"]')
        d = {}
        for i in a:
            l = i.find('.//img').attrib['src']
            t = i.find('span').text
            p2 = {t: l}
            d.update(p2)
        return d
    def getTitle(self,html):
        try:
            result = str(html.xpath('/html/body/div[2]/h3/text()')).strip(" ['']") #[0]
            return result.replace('/', '')
        except:
            return ''
    def getActor(self,html):
        a = html.xpath('//a[@class="avatar-box"]')
        d = []
        for i in a:
            d.append(i.find('span').text)
        return d
    def getStudio(self,html):
        result1 = str(html.xpath('//p[contains(text(),"制作商: ")]/following-sibling::p[1]/a/text()')).strip(" ['']").replace("', '",' ')
        return result1
    def getRuntime(self,html):
        result1 = str(html.xpath('//span[contains(text(),"长度:")]/../text()')).strip(" ['分钟']")
        return result1
    def getLabel(self,html):
        result1 = str(html.xpath('//p[contains(text(),"系列:")]/following-sibling::p[1]/a/text()')).strip(" ['']")
        return result1
    def getNum(self,html):
        result1 = str(html.xpath('//span[contains(text(),"识别码:")]/../span[2]/text()')).strip(" ['']")
        return result1
    def getYear(self,html):
        try:
            result = str(re.search('\d{4}',self.getRelease(html)))
            return result
        except:
            return ""
    def getRelease(self,html):
        result1 = str(html.xpath('//span[contains(text(),"发行时间:")]/../text()')).strip(" ['']")
        return result1
    def getCover(self,html):
        result = str(html.xpath('/html/body/div[2]/div[1]/div[1]/a/img/@src')).strip(" ['']")
        return result
    def getCover_small(self,html):
        result = str(html.xpath('//*[@id="waterfall"]/div/a/div[1]/img/@src')).strip(" ['']")
        return result
    def getTag(self,html):
        x = html.xpath('/html/head/meta[@name="keywords"]/@content')
        if x:
            x =x [0].split(',')
            if len(x) > 2:
                return [i.strip() for i in x[2:]]
            else:
                return []
    def getSeries(self,html):
        try:
            result1 = str(html.xpath('//span[contains(text(),"系列:")]/../span[2]/text()')).strip(" ['']")
            return result1
        except:
            return ''

    def main(self,number):
        self.fx = firefox()
        html = self.fx.get_html('https://tellme.pw/avsox',time=1)
        site = etree.HTML(html).xpath('//div[@class="container"]/div/a/@href')[0]
        a = self.fx.get_html(site + '/cn/search/' + number,time=1)
        #print(site + '/cn/search/' + number)
        html = etree.fromstring(a, etree.HTMLParser())
        alert = str(html.xpath('//div[@class="alert alert-danger"]'))
        if alert:
            return self.info
        result1 = str(html.xpath('//*[@id="waterfall"]/div/a/@href')).strip(" ['']")
        if result1 == '' or result1 == 'null' or result1 == 'None':
            a = self.fx.get_html(site + '/cn/search/' + number.replace('-', '_'),time=1)
            html = etree.fromstring(a, etree.HTMLParser())
            result1 = str(html.xpath('//*[@id="waterfall"]/div/a/@href')).strip(" ['']")
            if result1 == '' or result1 == 'null' or result1 == 'None':
                a = self.fx.get_html(site + '/cn/search/' + number.replace('_', ''),time=1)
                html = etree.fromstring(a, etree.HTMLParser())
                result1 = str(html.xpath('//*[@id="waterfall"]/div/a/@href')).strip(" ['']")
        detail = self.fx.get_html("https:" + result1,time=1)
        self.lx = etree.fromstring(detail, etree.HTMLParser())
        self.getVideoInfo(self.lx)
        self.info['source'] = "avsox.py"
        self.info['website'] = "https:" + result1
        return self.info
        

if __name__ == "__main__":
    avs = Avsox()
    #print(avs.main('012717_472'))
    print(avs.main('SSIS-313'))
    #print(main('1')) # got fake result raise 'number not found'



import time
from selenium import  webdriver
from selenium.webdriver.common.by import By
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
from selenium.webdriver.firefox.options import Options
from lxml import etree#need install
import requests

class firefox(object):

    options = Options()
    options.headless = True

    def __init__(self):
        pass

    

    def get_html(self,url, wait_for= "",time = 10, firefox_locale = 'en-us',cookies=None):
        """
        开始爬虫
        :return:
        """

        # Set the locale
        firefox_profile = webdriver.FirefoxProfile()
        firefox_profile.set_preference("intl.accept_languages", firefox_locale)
        firefox_profile.update_preferences()
        self.options.profile = firefox_profile
        # get方式打开网页
        # url = "https://www.busdmm.fun/SSIS-356"
        #wait_for = "//a[@rel][@title]"
        self.driver = webdriver.Firefox(options=self.options)
        self.driver.implicitly_wait(time)

        self.driver.get(str(url))
        if cookies:
            self.driver.add_cookie(cookies)
            self.driver.get(str(url))
            
        if wait_for:
            element = WebDriverWait(self.driver,time).until(
                EC.presence_of_element_located((By.XPATH,wait_for))
            )

        self.page_source = self.driver.page_source
        self.driver.quit()
        return(self.page_source)
    
    def post_html(self,url, data, wait_for= "",time = 10, firefox_locale = 'en-us'):
        # Set the locale
        # get方式打开网页
        # url = "https://www.busdmm.fun/SSIS-356"
        #wait_for = "//a[@rel][@title]"
        self.response = requests.post(str(url),data=data)
        return(self.response.text)

        

# G_USER_AGENT = r'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/98.0.4758.102 Safari/537.36'
# url = "https://www.busdmm.fun/SSIS-313"
# baseurl = "https://www.busdmm.fun/SSIS-313"
# headers = {"user-Agent": G_USER_AGENT,
#            "referer": baseurl,
#            "x-requested-with": "XMLHttpRequest"}  # noqa
# result = requests.get(str(url), headers=headers)

# with open("tmp.html","w") as f:
#     f.write(result.text)
if __name__ == '__main__':
    # x = firefox()
    # url = "https://www.busdmm.fun/SSIS-356"
    # print(x.get_html(url))
    opts = FirefoxOptions()
    opts.add_argument("--headless")
    myfx = Firefox(options=opts)
    url="https://www.jav321.com/search"
    response = myfx.request('POST',url,data = {"sn": "jul-404"})
    print(response.text)
    myfx.quit()
    
    



import os
from .myairav import Airav
from .myavsox import Avsox
from .mycarib import Carib
from .mydlsite import Dlsite
from .myfanza import Fanza
from .myfc2 import Fc2
from .myfc2club import Fc2club
from .myjav321 import Jav321
from .myjavbus import Javbus
from .myjavdb import Javdb
from .mymgstage import Mgstage
from .mymv91 import Mv91
from .htmlclass import getVideoInfoBase


class register_db():
    registered_db = {}

    def register(self,dbclass):
        #print(dbclass.__class__.__name__)
        self.registered_db[dbclass.__class__.__name__] = dbclass

    def main(self):
        self.register(Javdb())
        self.register(Javbus())
        self.register(Jav321())
        self.register(Airav())
        self.register(Avsox())
        self.register(Carib())
        self.register(Dlsite())
        self.register(Fanza())
        self.register(Fc2())
        self.register(Fc2club())
        self.register(Mgstage())
        self.register(Mv91())
    
    
if __name__ == '__main__':
    db = register_db()
    print(db.registered_db)
    



import os
import sys
sys.path.append('../..')
from abc import abstractmethod, ABCMeta
from .htmlclass import *
from .firefox import firefox
#import test
from lxml import etree#need install
import re
import pprint
from urllib.parse import urljoin
import inspect
import secrets
from .myjavbus import Javbus

'''
myAPI
注册：https://www.airav.wiki/api/auth/signup
设置：https://www.airav.wiki/api/get_web_settings
搜索：https://www.airav.wiki/api/video/list?lng=zh-CN&search=
搜索：https://www.airav.wiki/api/video/list?lang=zh-TW&lng=zh-TW&search=
'''


class Airav(getVideoInfoBase):
    __metaclass__ = ABCMeta
    host = 'https://www.airav.wiki/video/'
    def __init__(self):
        super().__init__()
        
    def getMagnetLink(self,html):
        result = self.info.get('magnetlink')
        if isinstance(result, dict) and len(result):
            return result
        return ''
    # airav这个网站没有演员图片，所以直接使用javbus的图
    def getActorPhoto(self,html):
        result = self.info.get('actor_photo')
        if isinstance(result, dict) and len(result):
            return result
        return ''

    def getTitle(self,html):  #获取标题
        title = str(html.xpath('/html/head/title/text()')[0])
        result = str(re.findall('](.*?)- AIRAV-WIKI', title)[0]).strip()
        return result
    def getStudio(self,html): #获取厂商 已修改
        result = self.info.get('studio')
        if isinstance(result, str) and len(result):
            return result
        return str(html.xpath('//a[contains(@href,"?video_factory=")]/text()')).strip(" ['']")
    def getYear(self,html):   #获取年份
        result = self.info.get('year')
        if isinstance(result, str) and len(result):
            return result
        release = self.getRelease(html)
        if len(release) != len('2000-01-01'):
            return ''
        return release[:4]
    def getCover(self,html):  #获取封面图片
        result = self.info.get('cover')
        if isinstance(result, str) and len(result):
            return result
        return html.xpath('//img[contains(@src,"/storage/big_pic/")]/@src')[0]
    def getRelease(self,html): #获取出版日期
        result = self.info.get('release')
        if isinstance(result, str) and len(result):
            return result
        try:
            result = re.search(r'\d{4}-\d{2}-\d{2}', str(html.xpath('//li[contains(text(),"發片日期")]/text()'))).group()
        except:
            return ''
        return result
    def getRuntime(self,html): #获取播放时长
        result = self.info.get('runtime')
        if isinstance(result, str) and len(result):
            return result
        return ''
    # airav女优数据库较多日文汉字姓名，javbus较多日语假名，因此airav优先
    def getActor(self,html):   #获取女优
        b=[]
        a = html.xpath('//ul[@class="videoAvstarList"]/li/a[starts-with(@href,"/idol/")]/text()')
        for v in a:
            v = v.strip()
            if len(v):
                b.append(v)
        if len(b):
            return b
        result = self.info.get('actor')
        if isinstance(result, list) and len(result):
            return result
        return []
    def getNum(self,html):     #获取番号
        result = self.info.get('number')
        if isinstance(result, str) and len(result):
            return result
        title = str(html.xpath('/html/head/title/text()')[0])
        result = str(re.findall('^\[(.*?)]', title)[0])
        return result
    def getDirector(self,html): #获取导演 已修改
        result = self.info.get('director')
        if isinstance(result, str) and len(result):
            return result
        return ''
    def getOutline(self,html):  #获取概述
        try:
            result = html.xpath("string(//div[@class='d-flex videoDataBlock']/div[@class='synopsis']/p)").replace('\n','').strip()
            return result
        except:
            return ''
    def getSeries(self,html):   #获取系列 已修改
        result = self.info.get('series')
        if isinstance(result, str) and len(result):
            return result
        return ''
    def getTag(self,html):  # 获取标签
        tag = []
        result = html.xpath('//a[contains(@href,"?video_tag=")]/text()')
        tag.append(result)
    def getExtrafanart(self,html):  # 获取剧照
        elements = html.xpath('//div[@tabindex][contains(@class,"image-gallery-slid")]')
        imgs = []
        if elements:
            for a in elements[0].findall(".//img"):
                imgs.append(a.attrib["src"])

        #print(imgs)
        if imgs:
            return imgs
        return ''


    def main(self,number):
        self.fx = firefox()
        jb = Javbus()
        self.info = jb.main(number)
        url = self.host + number
        #wait_for = "//a[@rel][@title]"
        htmlcode = self.fx.get_html(url)
        #print(htmlcode)
        self.lx = etree.fromstring(htmlcode,etree.HTMLParser())
        self.getVideoInfo(self.lx)
        self.info['source'] = "airav.py"
        self.info['website'] = urljoin(self.host,number)
        return self.info

        
        #self.lx = etree.fromstring(htmlcode,etree.HTMLParser())
        #self.getVideoInfo(self.lx)
        #return self.info
    

if __name__ == '__main__':
    aa = Airav()
    info = aa.main('ADV-R0624')  # javbus页面返回404, airav有数据
    print(info)
    # print(main('ADV-R0624'))  # javbus页面返回404, airav有数据
    # print(main('ADN-188'))    # 一人
    # print(main('CJOD-278'))   # 多人 javbus演员名称采用日语假名，airav采用日文汉字



import os
import sys
sys.path.append('../..')
from abc import abstractmethod, ABCMeta
from .htmlclass import *
from .firefox import firefox
#import test
from lxml import etree#need install
import re
import pprint
from urllib.parse import urljoin
import inspect
import secrets

etree.FunctionNamespace("http://exslt.org/regular-expressions").prefix = 're'
# import io
# sys.stdout = io.TextIOWrapper(sys.stdout.buffer, errors = 'replace', line_buffering = True)

class Javdb(getVideoInfoBase):
    __metaclass__ = ABCMeta

    def __init__(self):
        super().__init__()

    def getMagnetLink(self,html):
        elements = html.xpath('//td[@class="magnet-name"]')
        video_lists = []
        for element in elements:
            #print(etree.tostring(element))
            info = VideoDownloadInfo()
            a = element.findall("./a[@href]")
            if a :
                info["magnetlink"] = a[0].attrib["href"]
                #print(element.attrib['onclick'])
                for text in element.itertext():
                    if re.findall("HD",text):
                        info["isHD"] = 1
                    if re.findall("GB",text):
                        info["size"] = re.findall("[0-9\.]+GB",text)[0]
                video_lists.append(info)

            if not video_lists:
                return ""
            else:
                video_lists = sorted(video_lists,key = lambda i:(i["isHD"],i["size"]),reverse=True)
        return video_lists


    def getTitle(self,html):
        browser_title = str(html.xpath("/html/head/title/text()")[0])
        return browser_title[:browser_title.find(' | JavDB')].strip()
    def getActor(self,html):
        actors = html.xpath('//span[@class="value"]/a[contains(@href,"/actors/")]/text()')
        genders = html.xpath('//span[@class="value"]/a[contains(@href,"/actors/")]/../strong/@class')
        r = []
        idx = 0
        actor_gendor = "female" # only female
        if not actor_gendor in ['female','male','both','all']:
            actor_gendor = 'female'
        for act in actors:
            if((actor_gendor == 'all')
            or (actor_gendor == 'both' and genders[idx] in ['symbol female', 'symbol male'])
            or (actor_gendor == 'female' and genders[idx] == 'symbol female')
            or (actor_gendor == 'male' and genders[idx] == 'symbol male')):
                r.append(act)
            idx = idx + 1
        return r

    def getaphoto(url, session):
        html_page = session.get(url).text if session is not None else get_html(url)
        img_prether = re.compile(r'<span class\=\"avatar\" style\=\"background\-image\: url\((.*?)\)')
        img_url = img_prether.findall(html_page)
        if img_url:
            return img_url[0]
        else:
            return ''

    def getActorPhoto(self,html, javdb_site, session):
        actorall = html.xpath('//strong[re:match(text(),"演員:|Actor(s)")]/../span/a[starts-with(@href,"/actors/")]')
        if not actorall:
            return {}
        a = getActor(html)
        actor_photo = {}
        for i in actorall:
            if i.text in a:
                actor_photo[i.text] = getaphoto(urljoin(f'https://{javdb_site}.com', i.attrib['href']), session)
        return actor_photo

    def getStudio(self,html):
        # html = etree.fromstring(a, etree.HTMLParser())  # //table/tr[1]/td[1]/text()
        # result1 = str(html.xpath('//strong[contains(text(),"片商")]/../span/text()')).strip(" ['']")
        # result2 = str(html.xpath('//strong[contains(text(),"片商")]/../span/a/text()')).strip(" ['']")
        # return str(result1 + result2).strip('+').replace("', '", '').replace('"', '')
        a = etree.tostring(html,encoding="unicode")
        patherr = re.compile(r'<strong>(片商|Maker)\:</strong>[\s\S]*?<a href=\".*?>(.*?)</a></span>')
        pianshang = patherr.findall(a)
        if pianshang:
            result = pianshang[0][1].strip()
            if len(result):
                return result
        # 以卖家作为工作室
        try:
            result = str(html.xpath('//strong[contains(text(),"賣家:")]/../span/a/text()')).strip(" ['']")
        except:
            result = ''
        return result

    def getRuntime(self,html):
        result1 = str(html.xpath('//strong[re:match(text(),"時長|Duration")]/../span/text()')).strip(" ['']")
        result2 = str(html.xpath('//strong[re:match(text(),"時長|Duration")]/../span/a/text()')).strip(" ['']")
        return str(result1 + result2).strip('+').rstrip('mi')
    def getLabel(self,html):
        result1 = str(html.xpath('//strong[re:match(text(),"系列|Series")]/../span/text()')).strip(" ['']")
        result2 = str(html.xpath('//strong[re:match(text(),"系列|Series")]/../span/a/text()')).strip(" ['']")
        return str(result1 + result2).strip('+').replace("', '", '').replace("\"", '')
    def getNum(self,html):
        result1 = str(html.xpath('//strong[re:match(text(),"番號|ID:")]/../span/text()')).strip(" ['']")
        result2 = str(html.xpath('//strong[re:match(text(),"番號|ID:")]/../span/a/text()')).strip(" ['']")
        return str(result2 + result1).strip('+')
    def getYear(self,html):
        # try:
        #     result = str(re.search('\d{4}', getRelease).group())
        #     return result
        # except:
        #     return getRelease
        a = etree.tostring(html,encoding="unicode")
        patherr = re.compile(r'<strong>(日期|Released Date)\:</strong>\s*?.*?<span class="value">(.*?)\-.*?</span>')
        dates = patherr.findall(a)
        if dates:
            result = dates[0][1]
        else:
            result = ''
        return result

    def getRelease(self,html):
        # html = etree.fromstring(a, etree.HTMLParser())  # //table/tr[1]/td[1]/text()
        # result1 = str(html.xpath('//strong[contains(text(),"時間")]/../span/text()')).strip(" ['']")
        # result2 = str(html.xpath('//strong[contains(text(),"時間")]/../span/a/text()')).strip(" ['']")
        # return str(result1 + result2).strip('+')
        a = etree.tostring(html,encoding="unicode")
        patherr = re.compile(r'<strong>(日期|Released Date)\:</strong>\s*?.*?<span class="value">(.*?)</span>')
        dates = patherr.findall(a)
        if dates:
            result = dates[0][1]
        else:
            result = ''
        return result
    def getTag(self,html):
        try:
            result = html.xpath('//strong[re:match(text(),"類別|Tags")]/../span/a/text()')
            return result
        except:
            result = html.xpath('//strong[re:match(text(),"類別|Tags")]/../span/text()')
            return result

    def getCover_small(self,html, index=0):
        # same issue mentioned below,
        # javdb sometime returns multiple results
        # DO NOT just get the firt one, get the one with correct index number
        try:
            result = html.xpath("//div[@class='item-image fix-scale-cover']/img/@src")[index]
            if not 'https' in result:
                result = 'https:' + result
            return result
        except: # 2020.7.17 Repair Cover Url crawl
            try:
                result = html.xpath("//div[@class='item-image fix-scale-cover']/img/@data-src")[index]
                if not 'https' in result:
                    result = 'https:' + result
                return result
            except:
                result = html.xpath("//div[@class='item-image']/img/@data-src")[index]
                if not 'https' in result:
                    result = 'https:' + result
                return result


    def getTrailer(self,html):  # 获取预告片
        video_pather = re.compile(r'<video id\=\".*?>\s*?<source src=\"(.*?)\"')
        video = video_pather.findall(htmlcode)
        # 加上数组判空
        if video and video[0] != "":
            if not 'https:' in video[0]:
                video_url = 'https:' + video[0]
            else:
                video_url = video[0]
        else:
            video_url = ''
        return video_url

    def getExtrafanart(self,html):  # 获取剧照
        result = []
        try:
            result = html.xpath("//article[@class='message video-panel']/div[@class='message-body']/div[@class='tile-images preview-images']/a[contains(@href,'/samples/')]/@href")
        except:
            pass
        return result
    def getCover(self,html):
        result = ''
        try:
            res = html.xpath("//div[contains(@class, 'column-video-cover')]/a/img/@src")
            if res:
                result =  res[0]
        except: # 2020.7.17 Repair Cover Url crawl
            res = html.xpath("//div[contains(@class, 'column-video-cover')]/img/@src")
            if res:
                result =  res[0]
        return result
    def getDirector(self,html):
        result1 = str(html.xpath('//strong[re:match(text(),"導演|Director")]/../span/text()')).strip(" ['']")
        result2 = str(html.xpath('//strong[re:match(text(),"導演|Director")]/../span/a/text()')).strip(" ['']")
        return str(result1 + result2).strip('+').replace("', '", '').replace("\"", '')
    def getOutline(self,html):  #获取剧情介绍 多进程并发查询
        return ""
    def getSeries(self,html):
        result1 = str(html.xpath('//strong[re:match(text(),"系列|Series")]/../span/text()')).strip(" ['']")
        result2 = str(html.xpath('//strong[re:match(text(),"系列|Series")]/../span/a/text()')).strip(" ['']")
        return str(result1 + result2).strip('+').replace("', '", '').replace("\"", '')

    def main(self,number):
        # javdb更新后同一时间只能登录一个数字站，最新登录站会踢出旧的登录，因此按找到的第一个javdb*.json文件选择站点，
        # 如果无.json文件或者超过有效期，则随机选择一个站点。
        javdb_sites = [""]
        for i in javdb_sites:
            javdb_sites[javdb_sites.index(i)] = "javdb" + i
        javdb_sites.append("javdb")
        ## print(javdb_sites)
        javdb_site = secrets.choice(javdb_sites)
        #print(f'[!]javdb:select site {javdb_site}')
        javdb_url = 'https://' + javdb_site + '.com/search?q=' + number + '&f=all'
        self.fx = firefox()
        htmlcode = self.fx.get_html(url = javdb_url, time = 1)
        #print(htmlcode)
        #print(javdb_url)
        html = etree.fromstring(htmlcode, etree.HTMLParser())  # //table/tr[1]/td[1]/text()
        # javdb sometime returns multiple results,
        # and the first elememt maybe not the one we are looking for
        # iterate all candidates and find the match one
        urls = html.xpath('//*[@id="videos"]/div/div/a/@href')
        # 记录一下欧美的ids  ['Blacked','Blacked']
        if re.search(r'[a-zA-Z]+\.\d{2}\.\d{2}\.\d{2}', number):
            correct_url = urls[0]
        else:
            ids = html.xpath('//*[@id="videos"]/div/div/a/div[contains(@class, "uid")]/text()')
            #print(ids)
            try:
                correct_url = urls[ids.index(number)]
            except:
                # 为避免获得错误番号，只要精确对应的结果
                if ids[0].upper() != number:
                    raise ValueError("number not found")
        # get faster benefit from http keep-alive
        # print(correct_url)
        javdb_detail_url = 'https://' + javdb_site + '.com' + correct_url
        # print(javdb_detail_url)
        detail_page = self.fx.get_html(javdb_detail_url,time = 1)
        # etree.fromstring开销很大，最好只用一次，而它的xpath很快，比bs4 find/select快，可以多用
        #print(detail_page)
        self.lx = etree.fromstring(detail_page, etree.HTMLParser())
        #no cut image by default
        #If gray image exists ,then replace with normal cover
        self.getVideoInfo(self.lx)
        return self.info

    def getUrls(self, html):
        pagination = html.xpath("//ul[@class=\"pagination-list\"]")
        #print(pagination)
        urls = []
        if pagination:
            pages = pagination[0].findall('.//a[@class="pagination-link"]')
            #print(pages)
            if pages:
                for page in pages:
                    #print(page)
                    urls.append(self.urlbase + page.attrib["href"])
        #print(urls)
        ## only return three pages
        n = 3 if len(urls) >=3 else len(urls)
        return urls[0:(n-1)]

    def getVideoList(self,html):
        elements = html.xpath('//div[contains(@class,"grid-item column")]')
        if elements:
            for element in elements:
                info = VideoInfo()
                id = element.findall('.//div[@class="uid"]')
                if id:
                    info["number"] = id[0].text
                title = element.findall('.//a[@href][@class="box"][@title]')
                if title:
                    info["website"] = self.urlbase + title[0].attrib['href']
                    info["title"] = title[0].attrib['title']
                cover = element.findall(".//img")
                if cover:
                    info["cover"] = cover[0].attrib['data-src']
                    self.videoList.append(info)

    def search(self,keyword):
        javdb_sites = ["33","34"]
        for i in javdb_sites:
            javdb_sites[javdb_sites.index(i)] = "javdb" + i
        javdb_sites.append("javdb")
        ## print(javdb_sites)
        javdb_site = secrets.choice(javdb_sites)
        #print(f'[!]javdb:select site {javdb_site}')
        self.fx = firefox()
        self.urlbase = 'https://' + javdb_site + '.com'
        url = self.urlbase +  '/search?q=' + keyword + '&f=all'
        #wait_for = "//a[@rel][@title]"
        htmlcode = self.fx.get_html(url,time =1)
        #print(htmlcode)
        #print(url)
        self.lx = etree.fromstring(htmlcode,etree.HTMLParser())

    def searchKeyword(self,keyword):
        self.search(keyword)
        self.videoList = []
        urls = self.getUrls(self.lx)
        if urls:
            for url in urls:
                htmlcode = self.fx.get_html(url,time = 1)
                lx = etree.fromstring(htmlcode,etree.HTMLParser())
                self.getVideoList(lx)
        else:
            self.getVideoList(self.lx)
        return self.videoList




# main('DV-1562')
# input("[+][+]Press enter key exit, you can check the error messge before you exit.\n[+][+]按回车键结束，你可以在结束之前查看和错误信息。")
if __name__ == "__main__":
    jav = Javdb()
    # print(main('blacked.20.05.30'))
    #print(jav.main('AGAV-042'))
    print(jav.searchKeyword('三上悠亜'))
    # print(main('BANK-022'))
    # print(main('070116-197'))
    # print(main('093021_539'))  # 没有剧照 片商pacopacomama
    #print(main('FC2-2278260'))
    # print(main('FC2-735670'))
    # print(main('FC2-1174949')) # not found
    #print(main('MVSD-439'))
    # print(main('EHM0001')) # not found
    # print(jav.main('FC2-2314275'))
    # print(main('EBOD-646'))
    # print(main('LOVE-262'))
    #print(main('ABP-890'))



import os
import sys
sys.path.append('../..')
from abc import abstractmethod, ABCMeta
from .htmlclass import *
from .firefox import firefox
#import test
from lxml import etree#need install
import re
import pprint
from urllib.parse import urljoin
import inspect

import secrets

etree.FunctionNamespace("http://exslt.org/regular-expressions").prefix = 're'
# import io
# sys.stdout = io.TextIOWrapper(sys.stdout.buffer, errors = 'replace', line_buffering = True)

class Mv91(getVideoInfoBase):
    __metaclass__ = ABCMeta

    host = 'https://www.91mv.org'
    def __init__(self):
        super().__init__()

    def getActorPhoto(self,html):
        return ''

    def getTitle(self,html):  #获取标题
        try:
            title = str(html.xpath('//div[@class="player-title"]/text()')[0])
            result = str(re.findall('(.*)(91.*-\d*)',title)[0][0])
            return result.strip()
        except:
            return ''

    def getStudio(self,html): #获取厂商 已修改
        return '91制片厂'

    def getYear(self,html):   #获取年份
        try:
            result = str(html.xpath('//p[@class="date"]/text()')[0])
            date = result.replace('日期：','')
            if isinstance(date, str) and len(date):
                return date
        except:
            return ''
        return ''

    def getCover(self,html):  #获取封面图片
        htmlcode = etree.tostring(html,encoding="unicode")
        try:
            url = str(re.findall('var pic_url = "(.*?)"',htmlcode)[0])
            return url.strip()
        except:
            return ''

    def getRelease(self,html): #获取出版日期
        try:
            result = str(html.xpath('//p[@class="date"]/text()')[0])
            date = result.replace('日期：','')
            if isinstance(date, str) and len(date):
                return date
        except:
            return ''
        return ''

    def getRuntime(self,html): #获取播放时长
        return ''

    def getActor(self,html):   #获取女优
        b=[]
        for player in html.xpath('//p[@class="player-name"]/text()'):
            player = player.replace('主演：','')
            b.append(player)
        return b

    def getNum(self,html):     #获取番号
        try:
            title = str(html.xpath('//div[@class="player-title"]/text()')[0])
            result = str(re.findall('(.*)(91.*-\d*)',title)[0][1])
            return result.strip()
        except:
            return ''

    def getDirector(self,html): #获取导演 已修改
        return ''

    def getOutline(self,html):  #获取概述
        try:
            result = str(html.xpath('//div[@class="play-text"]/text()')[0])
            return result.strip()
        except:
            return ''


    def getSerise(self,html):   #获取系列 已修改
        return ''

    def getTag(self,html):  # 获取标签
        return html.xpath('//div[@class="player-tag"]/text()')

    def getExtrafanart(self,html):  # 获取剧照
        return ''

    def search(self,keyword): #搜索，返回结果
        self.fx = firefox()
        search_html = self.fx.get_html(self.host + '/index/search?keywords=' + keyword)
        html = etree.fromstring(search_html, etree.HTMLParser())
        video_list = html.xpath('//a[@class="video-list"]/@href')
        return video_list[0] if video_list else ''

    def main(self,number):
        number = number.replace('91CM-','').replace('91MS-','')
        url = self.host + str(self.search(number))
        self.fx = firefox()
        htmlcode = self.fx.get_html(url,time = 1)
        self.lx = etree.fromstring(htmlcode,etree.HTMLParser())
        #print(htmlcode)
        #print(url)
        self.getVideoInfo(self.lx)
        return self.info



if __name__ == '__main__':
    jav = Mv91()
    print(jav.main('91CM-121'))
    #print(main('91CM-122'))
    #print(main('91CM-143'))
    #print(main('91MS-006'))



# -*- coding: utf-8 -*-
import os
import sys
sys.path.append('../..')
from abc import abstractmethod, ABCMeta
from .htmlclass import *
from .firefox import firefox
#import test
from lxml import etree#need install
import re
import pprint
from urllib.parse import urljoin, urlencode
import inspect

import secrets

# import sys
# import io
# sys.stdout = io.TextIOWrapper(sys.stdout.buffer, errors = 'replace', line_buffering = True)

class Fanza(getVideoInfoBase):
    __metaclass__ = ABCMeta

    def __init__(self):
        super().__init__()

    def getTitle(self,html):
        result = html.xpath('//*[starts-with(@id, "title")]/text()')[0]
        return result
    def getActor(self,html):
        # //*[@id="center_column"]/div[2]/div[1]/div/table/tbody/tr[1]/td/text()
        result = (
            str(
                html.xpath(
                    "//td[contains(text(),'出演者')]/following-sibling::td/span/a/text()"
                )
            )
            .strip(" ['']")
            .replace("', '", ",")
        )
        return result


    def getStudio(self,html):
        try:
            result = html.xpath(
                "//td[contains(text(),'メーカー')]/following-sibling::td/a/text()"
            )[0]
        except:
            result = html.xpath(
                "//td[contains(text(),'メーカー')]/following-sibling::td/text()"
            )[0]
        return result


    def getRuntime(self,html):
        result = html.xpath("//td[contains(text(),'収録時間')]/following-sibling::td/text()")[0]
        return re.search(r"\d+", str(result)).group()


    def getLabel(self,html):
        try:
            result = html.xpath(
                "//td[contains(text(),'レーベル：')]/following-sibling::td/a/text()"
            )[0]
        except:
            result = html.xpath(
                "//td[contains(text(),'レーベル：')]/following-sibling::td/text()"
            )[0]
        return result


    def getNum(self,html):
        try:
            result = html.xpath(
                "//td[contains(text(),'品番：')]/following-sibling::td/a/text()"
            )[0]
        except:
            result = html.xpath(
                "//td[contains(text(),'品番：')]/following-sibling::td/text()"
            )[0]
        return result


    def getYear(self,html):
        try:
            result = str(re.search(r"\d{4}", self.getRelease(html)).group())
            return result
        except:
            return self.getRelease(html)


    def getRelease(self,html):
        try:
            result = html.xpath(
                "//td[contains(text(),'発売日：')]/following-sibling::td/a/text()"
            )[0].lstrip("\n")
        except:
            try:
                result = html.xpath(
                    "//td[contains(text(),'発売日：')]/following-sibling::td/text()"
                )[0].lstrip("\n")
            except:
                result = "----"
        if result == "----":
            try:
                result = html.xpath(
                    "//td[contains(text(),'配信開始日：')]/following-sibling::td/a/text()"
                )[0].lstrip("\n")
            except:
                try:
                    result = html.xpath(
                        "//td[contains(text(),'配信開始日：')]/following-sibling::td/text()"
                    )[0].lstrip("\n")
                except:
                    pass
        return result.replace("/", "-")


    def getTag(self,html):
        try:
            result = html.xpath(
                "//td[contains(text(),'ジャンル：')]/following-sibling::td/a/text()"
            )
            return result
        except:
            result = html.xpath(
                "//td[contains(text(),'ジャンル：')]/following-sibling::td/text()"
            )
            return result


    def getCover(self,html):
        cover_number = self.getNum(html)
        try:
            result = html.xpath('//*[@id="' + cover_number + '"]/@href')[0]
        except:
            # sometimes fanza modify _ to \u0005f for image id
            if "_" in cover_number:
                cover_number = cover_number.replace("_", r"\u005f")
            try:
                result = html.xpath('//*[@id="' + cover_number + '"]/@href')[0]
            except:
                # (TODO) handle more edge case
                # print(html)
                # raise exception here, same behavior as before
                # people's major requirement is fetching the picture
                raise ValueError("can not find image")
        return result


    def getDirector(self,html):
        try:
            result = html.xpath(
                "//td[contains(text(),'監督：')]/following-sibling::td/a/text()"
            )[0]
        except:
            result = html.xpath(
                "//td[contains(text(),'監督：')]/following-sibling::td/text()"
            )[0]
        return result


    def getOutline(self,html):
        try:
            result = str(html.xpath("//div[@class='mg-b20 lh4']/text()")[0]).replace(
                "\n", ""
            )
            if result == "":
                result = str(html.xpath("//div[@class='mg-b20 lh4']//p/text()")[0]).replace(
                    "\n", ""
                )
        except:
            # (TODO) handle more edge case
            # print(html)
            return ""
        return result


    def getSeries(self,html):
        try:
            try:
                result = html.xpath(
                    "//td[contains(text(),'シリーズ：')]/following-sibling::td/a/text()"
                )[0]
            except:
                result = html.xpath(
                    "//td[contains(text(),'シリーズ：')]/following-sibling::td/text()"
                )[0]
            return result
        except:
            return ""

    def getExtrafanart(self,html):  # 获取剧照
        elements = html.xpath('//div[@id="sample-image-block"]')
        imgs = []
        if elements:
            for a in elements[0].findall(".//img"):
                imgs.append(a.attrib["src"])

            #print(imgs)
        if not imgs:
            return ''
        return imgs


    def main(self,number):
        # fanza allow letter + number + underscore, normalize the input here
        # @note: I only find the usage of underscore as h_test123456789
        fanza_search_number = number
        # AV_Data_Capture.py.getNumber() over format the input, restore the h_ prefix
        if fanza_search_number.startswith("h-"):
            fanza_search_number = fanza_search_number.replace("h-", "h_")

        fanza_search_number = re.sub(r"[^0-9a-zA-Z_]", "", fanza_search_number).lower()

        fanza_urls = [
            "https://www.dmm.co.jp/digital/videoa/-/detail/=/cid=",
            "https://www.dmm.co.jp/mono/dvd/-/detail/=/cid=",
            "https://www.dmm.co.jp/digital/anime/-/detail/=/cid=",
            "https://www.dmm.co.jp/mono/anime/-/detail/=/cid=",
            "https://www.dmm.co.jp/digital/videoc/-/detail/=/cid=",
            "https://www.dmm.co.jp/digital/nikkatsu/-/detail/=/cid=",
            "https://www.dmm.co.jp/rental/-/detail/=/cid=",
        ]
        chosen_url = ""
        self.fx = firefox()
        for url in fanza_urls:
            chosen_url = url + fanza_search_number
            htmlcode = self.fx.get_html(
                "https://www.dmm.co.jp/age_check/=/declared=yes/?{}".format(
                    urlencode({"rurl": chosen_url})
                )
            )
            if "404 Not Found" not in htmlcode:
                break
        if "404 Not Found" in htmlcode:
            return json.dumps({"title": "",})
        #print(htmlcode)
        self.lx = etree.fromstring(htmlcode,etree.HTMLParser())
        self.getVideoInfo(self.lx)
        #print(chosen_url)
        self.info['source'] = "fanza.py"
        self.info['website'] = chosen_url
        return self.info



if __name__ == "__main__":
    # print(main("DV-1562"))
    # print(main("96fad1217"))
    fz = Fanza()
    print(fz.main("pred00251"))



import os
import sys
sys.path.append('../..')
from abc import abstractmethod, ABCMeta
from .htmlclass import *
from .firefox import firefox
#import test
from lxml import etree#nimport re
import pprint
from urllib.parse import urljoin
import inspect
import re
import secrets

class Javbus(getVideoInfoBase):
      __metaclass__ = ABCMeta

      def __init__(self):
            super().__init__()
            

      def getMagnetLink(self,html):
            elements = html.xpath('//tr[@onmouseover]')
            video_lists = []
            for element in elements:
                  #print(etree.tostring(element))
                  info = VideoDownloadInfo()
                  a = element.findall("./td/a[@rel]")
                  if a :
                        info["magnetlink"] = a[0].attrib["href"]
                        #print(element.attrib['onclick'])
                        for text in element.itertext():
                              if re.findall("高清",text):
                                    info["isHD"] = 1
                              if re.findall("字幕",text):
                                    info["isChn"] = 1
                              if re.findall("GB",text):
                                    info["size"] = re.findall(".+GB",text)[0]
                              if re.findall("\d+-\d+-\d+",text):
                                    info["date"] = re.findall("\d+-\d+-\d+",text)[0]
                        video_lists.append(info)

            if not video_lists:
                  return ""
            else:
                  video_lists = sorted(video_lists,key = lambda i:(i["isChn"],i["isHD"],i["date"]),reverse=True)
                  return video_lists

      def getActorPhoto(self,html):
          actors = html.xpath('//div[@class="star-name"]/a')
          d={}
          for i in actors:
              url=i.attrib['href']
              t=i.attrib['title']
              html = etree.fromstring(self.fx.get_html(url), etree.HTMLParser())
              p=urljoin("https://www.javbus.com",
                        str(html.xpath('//*[@id="waterfall"]/div[1]/div/div[1]/img/@src')).strip(" ['']"))
              p2={t:p}
              d.update(p2)
          return d
      def getTitle(self,html):  #获取标题
            title = str(html.xpath('/html/head/title/text()')[0])
            title = str(re.findall('^.+?\\s+(.*) - JavBus$', title)[0]).strip()
            return title
      def getStudioJa(self,html):
            x = html.xpath('//span[contains(text(),"メーカー:")]/../a/text()')
            return str(x[0]) if len(x) else ''
      def getStudio(self,html): #获取厂商
            x = html.xpath('//span[contains(text(),"製作商:")]/../a/text()')
            return str(x[0]) if len(x) else ''
      def getYear(self,html):   #获取年份
            result = str(html.xpath('/html/body/div[5]/div[1]/div[2]/p[2]/text()')).strip(" ['']").strip()
            return result[:4] if len(result)>=len('2000-01-01') else ''
      def getCover(self,html):  #获取封面链接
            image = html.xpath('//a[@class="bigImage"]/@href')
            if image:
                  image = str([0])
                  return urljoin("https://www.javbus.com", image)
            else:
                  return ''
      def getRelease(self,html): #获取出版日期
          result = str(html.xpath('/html/body/div[5]/div[1]/div[2]/p[2]/text()')).strip(" ['']")
          return result
      def getRuntime(self,html): #获取分钟 已修改
          result = str(html.xpath('/html/body/div[5]/div[1]/div[2]/p[3]/text()')).strip(" ['']分鐘")
          return result
      def getActor(self,html):   #获取女优
          b=[]
          actors = html.xpath('//div[@class="star-name"]/a')
          for i in actors:
              b.append(i.attrib['title'])
          return b
      def getNum(self,html):     #获取番号
          kwdlist = html.xpath('/html/head/meta[@name="keywords"]/@content')[0].split(',')
          return kwdlist[0]
      def getDirectorJa(self,html):
          x = html.xpath('//span[contains(text(),"監督:")]/../a/text()')
          return str(x[0]) if len(x) else ''
      def getDirector(self,html): #获取导演
          x = html.xpath('//span[contains(text(),"導演:")]/../a/text()')
          return str(x[0]) if len(x) else ''
      def getCID(self,html):
          string = html.xpath("//a[contains(@class,'sample-box')][1]/@href")[0].replace('https://pics.dmm.co.jp/digital/video/','')
          result = re.sub('/.*?.jpg','',string)
          return result
      def getOutline(self,html):  #获取剧情介绍 多进程并发查询
            return ""
      def getSeriseJa(self,html):
          x = html.xpath('//span[contains(text(),"シリーズ:")]/../a/text()')
          return str(x[0]) if len(x) else ''
      def getSeries(self,html):   #获取系列
          x = html.xpath('//span[contains(text(),"系列:")]/../a/text()')
          return str(x[0]) if len(x) else ''
      def getTag(self,html):  # 获取标签
          klist = html.xpath('/html/head/meta[@name="keywords"]/@content')[0].split(',')
          return klist[1:]
      def getExtrafanart(self,html):  # 获取剧照
            elements = html.xpath('//div[@id="sample-waterfall"]')
            imgs = []
            if elements:
                  for a in elements[0].findall(".//img"):
                        imgs.append(urljoin('https://www.javbus.com',a.attrib["src"]))

            #print(imgs)
            if not imgs:
                  return ''
            return imgs
            
      def main(self,number):
            self.info['source'] = "javbus.py"
            self.info['website'] = urljoin("https://www.javbus.com/",number)
            self.fx = firefox()
            self.urlbase = "https://www." + secrets.choice([
                'buscdn.fun', 'busdmm.fun', 'busfan.fun', 'busjav.fun',
                'cdnbus.fun',
                'dmmbus.fun', 'dmmsee.fun',
                'fanbus.us',
                'seedmm.fun',
            ])
            url = self.urlbase + "/" +number
            #print(url)
            #wait_for = "//a[@rel][@title]"
            htmlcode = self.fx.get_html(url,time =1)
            #print(htmlcode)
            self.lx = etree.fromstring(htmlcode,etree.HTMLParser())
            self.getVideoInfo(self.lx)
            return self.info

      def getUrls(self, html):
            pagination = html.xpath("//ul[@class=\"pagination pagination-lg\"]")
            urls = []
            if pagination:
                  for page in pagination[0].findall(".//a[@href]"):
                        urls.append(self.urlbase + page.attrib["href"])
            n = 3 if len(urls) >=3 else len(urls)
            return urls[0:(n-1)]

      def getVideoList(self,html):
            elements = html.xpath('//a[@class="movie-box"]')
            if elements:
                  for element in elements:
                        info = VideoInfo()
                        id = element.findall('.//date')
                        if id:
                              info["website"] = self.urlbase + element.attrib['href']
                              info["number"] = id[0].text
                              cover = element.findall(".//img")
                              if cover:
                                    info["cover"] = self.urlbase + cover[0].attrib['src']
                                    info["title"] = cover[0].attrib['title']
                        self.videoList.append(info)

      def search(self,keyword):
            self.info['source'] = "javbus.py"
            self.info['website'] = urljoin("https://www.javbus.com/search/",keyword)
            self.fx = firefox()
            self.urlbase = "https://www." + secrets.choice([
                'buscdn.fun', 'busdmm.fun', 'busfan.fun', 'busjav.fun',
                'cdnbus.fun',
                'dmmbus.fun', 'dmmsee.fun',
                'fanbus.us',
                'seedmm.fun',
            ])
            url = self.urlbase + "/search/" + keyword
            #wait_for = "//a[@rel][@title]"
            htmlcode = self.fx.get_html(url,time =1)
            #print(htmlcode)
            self.lx = etree.fromstring(htmlcode,etree.HTMLParser())

      def searchKeyword(self,keyword):
            self.search(keyword)
            self.videoList = []
            urls = self.getUrls(self.lx)
            if urls:
                  for url in urls:
                        htmlcode = self.fx.get_html(url,time = 1)
                        lx = etree.fromstring(htmlcode,etree.HTMLParser())
                        self.getVideoList(lx)
            else:
                  self.getVideoList(self.lx)
                  return self.videoList


if __name__ == "__main__":
      jav = Javbus()
      info = jav.main("SSIS-313")
      print(info)
      # jb = JavBus()
      # info = jb.main("SSIS-356")
      # print(info)
      #jav.searchKeyword("三上悠亜")
        



import os
import sys
sys.path.append('../..')
from abc import abstractmethod, ABCMeta
from .htmlclass import *
from .firefox import firefox
#import test
from lxml import etree#need install
import re
import pprint
from urllib.parse import urljoin
import inspect

import secrets

class Fc2(getVideoInfoBase):
    __metaclass__ = ABCMeta

    def __init__(self):
        super().__init__()

    def getTitle(self,html): #获取厂商
        elements = html.xpath('//div[@class="items_article_headerInfo"]/h3/text()')
        if elements:
            result = elements[0]
            return result
        else:
            return ''
    def getActor(self,html):
        try:
            result = html.xpath('//*[@id="top"]/div[1]/section[1]/div/section/div[2]/ul/li[3]/a/text()')[0]
            return result
        except:
            return ''
    def getStudio(self,html): #获取厂商
        try:
            result = str(html.xpath('//*[@id="top"]/div[1]/section[1]/div/section/div[2]/ul/li[3]/a/text()')).strip(" ['']")
            return result
        except:
            return ''
    def getNum(self,html):     #获取番号
        result = str(html.xpath('/html/body/div[5]/div[1]/div[2]/p[1]/span[2]/text()')).strip(" ['']")
        return result
    def getRelease(self,html): #
        result = str(html.xpath('//*[@id="top"]/div[1]/section[1]/div/section/div[2]/div[2]/p/text()')).strip(" ['販売日 : ']").replace('/','-')
        return result
    def getCover(self,html): #获取厂商 #
        cover = str(html.xpath("//div[@class='items_article_MainitemThumb']/span/img/@src")).strip(" ['']")
        #result = str(html.xpath('//*[@id="top"]/div[1]/section[1]/div/section/div[1]/span/img/@src')).strip(" ['']")
        cover = urljoin('https://adult.contents.fc2.com', cover)
        return cover
    # def getOutline(htmlcode2):     #获取番号 #
    #     xpath_html = etree.fromstring(htmlcode2, etree.HTMLParser())
    #     path = str(xpath_html.xpath('//*[@id="top"]/div[1]/section[4]/iframe/@src')).strip(" ['']")
    #     html = etree.fromstring(ADC_function.get_html('https://adult.contents.fc2.com/'+path), etree.HTMLParser())
    #     print('https://adult.contents.fc2.com'+path)
    #     print(ADC_function.get_html('https://adult.contents.fc2.com'+path,cookies={'wei6H':'1'}))
    #     result = str(html.xpath('/html/body/div/text()')).strip(" ['']").replace("\\n",'',10000).replace("'",'',10000).replace(', ,','').strip('  ').replace('。,',',')
    #     return result
    def getTag(self,html):
        result = html.xpath("//a[@class='tag tagTag']/text()")
        return result
    def getYear(self,html):
        try:
            result = re.search('\d{4}',self.getRelease(html)).group()
            return result
        except:
            return ''

    def getExtrafanart(self,html):  # 获取剧照
        elements = html.xpath('//ul[@class="items_article_SampleImagesArea"]')
        imgs = []
        if elements:
            for a in elements[0].findall(".//img"):
                imgs.append(a.attrib["src"])
        if not imgs:
            return ''
        return imgs


    def getTrailer(self,html, number=""):
        video_pather = re.compile(r'\'[a-zA-Z0-9]{32}\'')
        video = video_pather.findall(self,html)
        if video:
            try:
                video_url = video[0].replace('\'', '')
                video_url = 'https://adult.contents.fc2.com/api/v2/videos/' + number + '/sample?key=' + video_url
                url_json = eval(ADC_function.get_html(video_url))['path'].replace('\\', '')
                return url_json
            except:
                return ''
        else:
            video_url = ''

    def main(self,number):
        self.fx = firefox()
        number = number.replace('FC2-', '').replace('fc2-', '')
        url = 'https://adult.contents.fc2.com/article/' + number + '/'
        htmlcode = self.fx.get_html(url,time =1)
        self.lx = etree.fromstring(htmlcode,etree.HTMLParser())
        #print(htmlcode)
        #print(url)
        actor = self.getActor(self.lx)
        self.getVideoInfo(self.lx)
        self.info['website'] = 'https://adult.contents.fc2.com/article/' + number + '/'
        self.info['source'] = 'https://adult.contents.fc2.com/article/' + number + '/'
        return self.info


if __name__ == '__main__':
    fc = Fc2()
    #print(fc.main('FC2-1787685'))
    print(fc.main('FC2-2086710'))




import os
import sys
sys.path.append('../..')
from abc import abstractmethod, ABCMeta
from .htmlclass import *
from .firefox import firefox
#import test
from lxml import etree#need install
import re
import pprint
from urllib.parse import urljoin
import inspect

import secrets

etree.FunctionNamespace("http://exslt.org/regular-expressions").prefix = 're'
# import io
# sys.stdout = io.TextIOWrapper(sys.stdout.buffer, errors = 'replace', line_buffering = True)

class Mgstage(getVideoInfoBase):
    __metaclass__ = ABCMeta

    def __init__(self):
        super().__init__()

    def getTitle(self,html):
        try:
            result = str(html.xpath('//*[@id="center_column"]/div[1]/h1/text()')).strip(" ['']")
            return result.replace('/', ',')
        except:
            return ''
    def getActor(self,html): #//*[@id="center_column"]/div[2]/div[1]/div/table/tbody/tr[1]/td/text()
        result1=str(html.xpath('//th[contains(text(),"出演：")]/../td/a/text()')).strip(" ['']").strip('\\n    ').strip('\\n')
        result2=str(html.xpath('//th[contains(text(),"出演：")]/../td/text()')).strip(" ['']").strip('\\n    ').strip('\\n')
        return str(result1+result2).strip('+').replace("', '",'').replace('"','').replace('/',',')
    def getStudio(self,html):
        result1=str(html.xpath('//th[contains(text(),"メーカー：")]/../td/a/text()')).strip(" ['']").strip('\\n    ').strip('\\n')
        result2=str(html.xpath('//th[contains(text(),"メーカー：")]/../td/text()')).strip(" ['']").strip('\\n    ').strip('\\n')
        return str(result1+result2).strip('+').replace("', '",'').replace('"','')
    def getRuntime(self,html):
        result1 = str(html.xpath('//th[contains(text(),"収録時間：")]/../td/a/text()')).strip(" ['']").strip('\\n    ').strip('\\n')
        result2 = str(html.xpath('//th[contains(text(),"収録時間：")]/../td/text()')).strip(" ['']").strip('\\n    ').strip('\\n')
        return str(result1 + result2).strip('+').rstrip('mi')
    def getLabel(self,html):
        result1 = str(html.xpath('//th[contains(text(),"シリーズ：")]/../td/a/text()')).strip(" ['']").strip('\\n    ').strip(
            '\\n')
        result2 = str(html.xpath('//th[contains(text(),"シリーズ：")]/../td/text()')).strip(" ['']").strip('\\n    ').strip(
            '\\n')
        return str(result1 + result2).strip('+').replace("', '",'').replace('"','')
    def getNum(self,html):
        result1 = str(html.xpath('//th[contains(text(),"品番：")]/../td/a/text()')).strip(" ['']").strip('\\n    ').strip(
            '\\n')
        result2 = str(html.xpath('//th[contains(text(),"品番：")]/../td/text()')).strip(" ['']").strip('\\n    ').strip(
            '\\n')
        return str(result1 + result2).strip('+')
    def getRelease(self,html):
        result1 = str(html.xpath('//th[contains(text(),"配信開始日：")]/../td/a/text()')).strip(" ['']").strip('\\n    ').strip(
            '\\n')
        result2 = str(html.xpath('//th[contains(text(),"配信開始日：")]/../td/text()')).strip(" ['']").strip('\\n    ').strip(
            '\\n')
        return str(result1 + result2).strip('+').replace('/','-')

    def getYear(self,html):
        try:
            result = str(re.search('\d{4}',self.getRelease(html)).group())
            return result
        except:
            return ''
    def getTag(self,html):
        result1 = str(html.xpath('//th[contains(text(),"ジャンル：")]/../td/a/text()')).strip(" ['']").strip('\\n    ').strip(
            '\\n')
        result2 = str(html.xpath('//th[contains(text(),"ジャンル：")]/../td/text()')).strip(" ['']").strip('\\n    ').strip(
            '\\n')
        result = str(result1 + result2).strip('+').replace("', '\\n",",").replace("', '","").replace('"','').replace(',,','').split(',')
        return result
    def getCover(self,html):
        result = str(html.xpath('//*[@id="EnlargeImage"]/@href')).strip(" ['']")
        # result = str(html.xpath('//*[@id="center_column"]/div[1]/div[1]/div/div/h2/img/@src')).strip(" ['']")
        #                    /html/body/div[2]/article[2]/div[1]/div[1]/div/div/h2/img/@src
        return result
    def getDirector(self,html):
        result1 = str(html.xpath('//th[contains(text(),"シリーズ")]/../td/a/text()')).strip(" ['']").strip('\\n    ').strip(
            '\\n')
        result2 = str(html.xpath('//th[contains(text(),"シリーズ")]/../td/text()')).strip(" ['']").strip('\\n    ').strip(
            '\\n')
        return str(result1 + result2).strip('+').replace("', '",'').replace('"','')
    def getOutline(self,html):
        result = str(html.xpath('//p/text()')).strip(" ['']").replace(u'\\n', '').replace("', '', '", '')
        return result
    def getSeries(self,html):
        result1 = str(html.xpath('//th[contains(text(),"シリーズ")]/../td/a/text()')).strip(" ['']").strip('\\n    ').strip(
            '\\n')
        result2 = str(html.xpath('//th[contains(text(),"シリーズ")]/../td/text()')).strip(" ['']").strip('\\n    ').strip(
            '\\n')
        return str(result1 + result2).strip('+').replace("', '", '').replace('"', '')

    def getExtrafanart(self,html):  # 获取剧照
        elements = html.xpath('//dl[@id="sample-photo"]')
        print(elements)
        imgs = []
        if elements:
            for a in elements[0].findall(".//a[@class='sample_image']"):
                imgs.append(a.attrib["href"])
                
        #print(imgs)
        if not imgs:
            return ''
        return imgs

    def main(self,number):
        number=number.upper()
        self.fx = firefox()
        url  = 'https://www.mgstage.com/product/product_detail/'+str(number)+'/'
        #print(url)
        htmlcode=self.fx.get_html(url,time=1,cookies={"name": "adc","value": "1"})
        #print(htmlcode)
        print(url)
        self.lx = etree.fromstring(htmlcode,etree.HTMLParser())
        self.getVideoInfo(self.lx)
        return self.info
        

if __name__ == '__main__':
    jav = Mgstage()
    #print(jav.main('SIRO-4149'))
    print(jav.main('SSIS-313'))



import os
import sys
sys.path.append('../..')
from abc import abstractmethod, ABCMeta
from .htmlclass import *
from .firefox import firefox
#import test
from lxml import etree#need install
import re
import pprint
from urllib.parse import urljoin
import inspect

import secrets

# import sys
# import io
# sys.stdout = io.TextIOWrapper(sys.stdout.buffer, errors = 'replace', line_buffering = True)
class Fc2club(getVideoInfoBase):
    __metaclass__ = ABCMeta

    def __init__(self):
        super().__init__()

    def getTitle(self,html): #获取标题
        result = str(html.xpath('//*[@class="show-top-grids"]/div[1]/h3/text()')).strip(" ['']")
        print(result)
        return result
    def getActor(self,html):
        try:
            result = str(html.xpath('//*[@class="show-top-grids"]/div[1]/h5[5]/a/text()')).strip(" ['']")
            print(result)
            return result
        except:
            return ''
    def getStudio(self,html): #获取厂商
        try:
            result = str(html.xpath('//*[@class="show-top-grids"]/div[1]/h5[3]/a[1]/text()')).strip(" ['']")
            print(result)
            return result
        except:
            return ''
    def getNum(self,html):     #获取番号
        title = str(html.xpath('//*[@class="show-top-grids"]/div[1]/h3/text()')).strip(" ['']")
        num = title.split(' ')[0]
        if num.startswith('FC2') != True:
            num = ''
        return num
    def getRelease(self,html): #
        return ''
    def getCover(self,html): #获取img #
        imgUrl = str(html.xpath('//*[@class="slides"]/li[1]/img/@src')).strip(" ['']")
        imgUrl = imgUrl.replace('../','https://fc2club.net/')
        print(imgUrl)
        return imgUrl
    def getOutline(self,html):     #获取番号 #
        path = str(html.xpath('//*[@id="top"]/div[1]/section[4]/iframe/@src')).strip(" ['']")
        result = str(html.xpath('/html/body/div/text()')).strip(" ['']").replace("\\n",'',10000).replace("'",'',10000).replace(', ,','').strip('  ').replace('。,',',')
        return result
    def getTag(self,html):     #获取tag
        a = html.xpath('//*[@class="show-top-grids"]/div[1]/h5[4]/a')
        tag = []
        for i in range(len(a)):
            tag.append(str(a[i].xpath('text()')).strip("['']"))
        return tag
    def getYear(self,html):
        return ''

    def getExtrafanart(self,html):  # 获取剧照
        imgUrl = str(html.xpath('//*[@class="slides"]/li[1]/img/@src')).strip(" ['']")
        imgUrl = imgUrl.replace('../','https://fc2club.net/')
        return imgUrl

    def getTrailer(self,html):
        return ''

    def main(self,number):
        self.fx = firefox()
        number = number.replace('FC2-', '').replace('fc2-', '')
        url = 'https://fc2club.net/html/FC2-' + number + '.html'
        htmlcode = self.fx.get_html(url,time =1)
        self.lx = etree.fromstring(htmlcode,etree.HTMLParser())
        #print(htmlcode)
        #print(url)
        self.getVideoInfo(self.lx)
        self.info['website'] = url
        self.info['source'] = url
        return self.info
    

if __name__ == '__main__':
    fc = Fc2club()
    print(fc.main('FC2-402422'))




# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['getmovieinfo', 'getmovieinfo.WebCrawler']

package_data = \
{'': ['*']}

install_requires = \
['argparse>=1.4.0,<2.0.0',
 'jsons>=1.6.1,<2.0.0',
 'lxml>=4.8.0,<5.0.0',
 'requests>=2.27.1,<3.0.0',
 'selenium>=4.1.3,<5.0.0']

entry_points = \
{'console_scripts': ['MovieInfo = getmovieinfo.MovieInfo:main']}

setup_kwargs = {
    'name': 'getmovieinfo',
    'version': '0.1.4',
    'description': 'Package to search specific video or keyword on a set of av websites',
    'long_description': '# MovieInfo\n\nMovieInfo is a tool to search specific number or keyword from a set of av and get information of videos and output json. This json is use for a discord bot or automation torrent download.\n\n\n### Installation\n\n```bash\npip install getmovieinfo\n```\n\n### Requirements\n\n#### python packages\n- python = "^3.7"\n- selenium = "^4.1.3"\n- requests = "^2.27.1"\n- lxml = "^4.8.0"\n- argparse = "^1.4.0"\n- jsons = "^1.6.1"\n- secrets\n\n#### other packages\n\n- firefox\n- [geckodriver](https://github.com/mozilla/geckodriver)\n\n### Usage\n\n```bash\nMovieInfo --number SSIS-356\n\nMovieInfo --keyword 涼森れむ\n```\n\n\n#### Parameters\n\n- --number\n  - Specify a video number\n- --keyword\n  - SPecify a keyword\n- --cache_dir\n  - specify a dir to store the result json\n\n\n# License\n\nThis project is licensed under the MIT License\n\n\n# Acknowledgement\n\nThis project is based on [Movie_data_Capture](https://github.com/yoshiko2/Movie_Data_Capture). \n\nI implement a keyword searching and standardize the infomation extractor from html.\n\nI update crawler to substitue python requests;\n\nSelenium is great at loading js on a web and enable the extracttion of torrent/magnet infomation. However this slows each request very much. Pay attention if you use this script to do massive query.\n',
    'author': 'crvidoeVR',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/crvideo/MovieInfo',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



import argparse
import jsons
import os
import re
import sys
from .WebCrawler.register import register_db
import os
import io


def argparse_function():
    parser = argparse.ArgumentParser()
    parser.add_argument("-n", "--number", default='', nargs='?', help="Custom file number to search all db.")
    parser.add_argument("-k", "--keyword", default='', nargs='?', help="Custom keyword to search two dbs.")	
    parser.add_argument("--cache_dir", default='~/.config/cache_dir', nargs='?', help="The path to save search results.")

    args = parser.parse_args()
    return args

def main():
    args = argparse_function()
    db = register_db()
    db.main()
    #print(db.registered_db)
    #print(args)
    if args.number:
        for dbname in ["Javbus","Javdb","Jav321","Carib","AVsox","Airav","Dlsite","Fanza","Fc2","Fc2club","Mgstage","Mv91"]:
            res = db.registered_db.get(dbname).main(args.number)
            if res['download']:
                #print(res)
                print(jsons.dumps(res['download'][0]))
                break
                
    if args.keyword:
        args.cache_dir = os.path.expanduser(args.cache_dir)
        #print(args.cache_dir)
        if not os.path.exists(args.cache_dir):
            os.makedirs(args.cache_dir,exist_ok=True)
        if not os.path.exists(args.cache_dir + "/" + args.keyword+".json"):
            for dbname in ["Javbus","Javdb"]:
                res = db.registered_db.get(dbname).searchKeyword(args.keyword)
                if res and res[0]["title"]:
                    with io.open(args.cache_dir + "/" + args.keyword + ".json","w",encoding='utf8') as f:
                        f.write(jsons.dumps(res))
                    break
            print(jsons.dumps(res))
        else:
            with open(args.cache_dir + "/" + args.keyword + ".json","r",encoding = 'utf8') as f:
                res = f.read()
                print(res)
        

if __name__ == '__main__':
    main()




import os
import sys
sys.path.append('../..')
from abc import abstractmethod, ABCMeta
from .htmlclass import *
from .firefox import firefox
#import test
from lxml import etree#need install
import re
import pprint
from urllib.parse import urljoin
import inspect
import json


# import sys
# import io
# sys.stdout = io.TextIOWrapper(sys.stdout.buffer, errors = 'replace', line_buffering = True)
#print(get_html('https://www.dlsite.com/pro/work/=/product_id/VJ013152.html'))
#title //*[@id="work_name"]/a/text()
#studio //th[contains(text(),"ブランド名")]/../td/span[1]/a/text()
#release //th[contains(text(),"販売日")]/../td/a/text()
#story //th[contains(text(),"シナリオ")]/../td/a/text()
#senyo //th[contains(text(),"声優")]/../td/a/text()
#tag //th[contains(text(),"ジャンル")]/../td/div/a/text()
#jianjie //*[@id="main_inner"]/div[3]/text()
#photo //*[@id="work_left"]/div/div/div[2]/div/div[1]/div[1]/ul/li/img/@src

#https://www.dlsite.com/pro/work/=/product_id/VJ013152.html
class Dlsite(getVideoInfoBase):
    __metaclass__ = ABCMeta
    
    def __init__(self):
        super().__init__()

    def getTitle(self,html):
        result = html.xpath('//*[@id="work_name"]/text()')
        return result[0] if result else ''
    def getActor(self,html):  # //*[@id="center_column"]/div[2]/div[1]/div/table/tbody/tr[1]/td/text()
        try:
            result1 = html.xpath('//th[contains(text(),"声优")]/../td/a/text()')
        except:
            result1 = ''
        return result1
    def getActorPhoto(self,html): #//*[@id="star_qdt"]/li/a/img
        a = actor.split(',')
        d={}
        for i in a:
            p={i:''}
            d.update(p)
        return d
    def getStudio(self,html):
        try:
            try:
                result = html.xpath('//th[contains(text(),"系列名")]/../td/span[1]/a/text()')[0]
            except:
                result = html.xpath('//th[contains(text(),"社团名")]/../td/span[1]/a/text()')[0]
        except:
            result = ''
        return result
    def getRuntime(self,html):
        result1 = str(html.xpath('//strong[contains(text(),"時長")]/../span/text()')).strip(" ['']")
        result2 = str(html.xpath('//strong[contains(text(),"時長")]/../span/a/text()')).strip(" ['']")
        return str(result1 + result2).strip('+').rstrip('mi')
    def getLabel(self,html):
        try:
            try:
                result = html.xpath('//th[contains(text(),"系列名")]/../td/span[1]/a/text()')[0]
            except:
                result = html.xpath('//th[contains(text(),"社团名")]/../td/span[1]/a/text()')[0]
        except:
            result = ''
        return result
    def getYear(self,html):
        try:
            result = str(re.search('\d{4}', self.getRelease(html)).group())
            return result
        except:
            return self.getRelease(html)
    def getRelease(self,html):
        result1 = html.xpath('//th[contains(text(),"贩卖日")]/../td/a/text()')
        return result1[0].replace('年','-').replace('月','-').replace('日','') if result1 else ''
    def getTag(self,html):
        try:
            result = html.xpath('//th[contains(text(),"分类")]/../td/div/a/text()')
            return result
        except:
            return ''
    def getCover_small(self,html,index=0):
        # same issue mentioned below,
        # javdb sometime returns multiple results
        # DO NOT just get the firt one, get the one with correct index number
        try:
            result = html.xpath("//div[@class='item-image fix-scale-cover']/img/@src")[index]
            if not 'https' in result:
                result = 'https:' + result
            return result
        except: # 2020.7.17 Repair Cover Url crawl
            result = html.xpath("//div[@class='item-image fix-scale-cover']/img/@data-src")[index]
            if not 'https' in result:
                result = 'https:' + result
            return result
    def getCover(self,html):
        result = html.xpath('//img/@srcset')
        return result[0] if result else ''
    def getDirector(self,html):
        try:
            result = html.xpath('//th[contains(text(),"剧情")]/../td/a/text()')[0]
        except:
            result = ''
        return result
    def getOutline(self,html):
        total = []
        result = html.xpath('//div[@class="work_parts_area"]/p/text()')
        for i in result:
            total.append(i.strip('\r\n'))
        return str(total).strip(" ['']").replace("', '', '",r'\n').replace("', '",r'\n').strip(", '', '")
    def getSeries(self,html):
        try:
            try:
                result = html.xpath('//th[contains(text(),"系列名")]/../td/span[1]/a/text()')[0]
            except:
                result = html.xpath('//th[contains(text(),"社团名")]/../td/span[1]/a/text()')[0]
        except:
            result = ''
        return result
    def main(self,number):
        self.fx = firefox()
        number = number.upper()
        url = 'https://www.dlsite.com/pro/work/=/product_id/' + number + '.html' +'/?locale=zh_cn'
        #print(url)
        htmlcode = self.fx.get_html(url,time =1)
        #print(htmlcode)
        self.lx = etree.fromstring(htmlcode,etree.HTMLParser())
        self.getVideoInfo(self.lx)
        self.info["website"] = url
        self.info["source"] = "dlsite.py"
        return self.info
    
# main('DV-1562')
# input("[+][+]Press enter key exit, you can check the error messge before you exit.\n[+][+]按回车键结束，你可以在结束之前查看和错误信息。")
if __name__ == "__main__":
    dl = Dlsite()
    print(dl.main('VJ013178'))



import os
import sys
sys.path.append('../..')
from abc import abstractmethod, ABCMeta
from .htmlclass import *
from .firefox import firefox
#import test
from lxml import etree#need install
import re
import pprint
from urllib.parse import urljoin
import inspect
import json

class Carib(getVideoInfoBase):
    __metaclass__ = ABCMeta
    
    def __init__(self):
        super().__init__()

    def getTitle(self,lx) -> str:
        element = str(lx.xpath("//div[@class='movie-info section']/div[@class='heading']/h1[@itemprop='name']/text()"))
        if element:
            return element[0].strip()
        else:
            return ''
    def getYear(self,lx) -> str:
        element =  lx.xpath("//li[2]/span[@class='spec-content']/text()")
        if element:
            return element[0][:4]
        else:
            return ''

    def getNum(self,lx):
        return self.number
    
    def getOutline(self,lx) -> str:
        o = lx.xpath("//div[@class='movie-info section']/p[@itemprop='description']/text()")
        if o:
            return o[0].strip()
        else:
            return ''

    def getRelease(self,lx) -> str:
        o = lx.xpath("//li[2]/span[@class='spec-content']/text()")
        if o:
            return o[0].replace('/','-')
        else:
            return ''

    def getActor(self,lx):
        r = []
        actors = lx.xpath("//span[@class='spec-content']/a[@itemprop='actor']/span/text()")
        for act in actors:
            if str(act) != '他':
                r.append(act)
        return r

    def getTag(self,lx) -> str:
        genres = lx.xpath("//span[@class='spec-content']/a[@itemprop='genre']/text()")
        return genres

    def getExtrafanart(self,lx) -> str:
        r = []
        genres = lx.xpath("//*[@id='sampleexclude']/div[2]/div/div[@class='grid-item']/div/a/img/@src")
        for g in genres:
            jpg = str(g)
            if '/member/' in jpg:
                break
            else:
                r.append('https://www.caribbeancom.com' + jpg)
        return r

    def getSeries(self,lx) -> str:
        try:
            return str(lx.xpath("//span[@class='spec-title'][contains(text(),'シリーズ')]/../span[@class='spec-content']/a/text()")[0]).strip()
        except:
            return ''

    def getRuntime(self,lx) -> str:
        o = str(lx.xpath("//span[@class='spec-content']/span[@itemprop='duration']/text()"))
        if o:
            return o[0].strip()
        else:
            return ''

    def getActorPhoto(self,lx):
        htmla = lx.xpath("//*[@id='moviepages']/div[@class='container']/div[@class='inner-container']/div[@class='movie-info section']/ul/li[@class='movie-spec']/span[@class='spec-content']/a[@itemprop='actor']")
        names = lx.xpath("//*[@id='moviepages']/div[@class='container']/div[@class='inner-container']/div[@class='movie-info section']/ul/li[@class='movie-spec']/span[@class='spec-content']/a[@itemprop='actor']/span[@itemprop='name']/text()")
        t = {}
        for name, a in zip(names, htmla):
            if name.strip() == '他':
                continue
            p = {name.strip(): a.attrib['href']}
            t.update(p)
        o = {}
        for k, v in t.items():
            if '/search_act/' not in v:
                continue
            r = self.fx.get_html(urljoin(G_SITE, v))
            if not r.ok:
                continue
            html = r.text
            pos = html.find('.full-bg')
            if pos<0:
                continue
            css = html[pos:pos+100]
            cssBGjpgs = re.findall(r'background: url\((.+\.jpg)', css, re.I)
            if not cssBGjpgs or not len(cssBGjpgs[0]):
                continue
            p = {k: urljoin(r.url, cssBGjpgs[0])}
            o.update(p)
        return o


    def main(self,number: str):
        G_SITE = 'https://www.caribbeancom.com'
        self.fx = firefox()
        url = f'{G_SITE}/moviepages/{number}/index.html'
        htmlcode = self.fx.get_html(url, time=1)
        #print(url)
        self.number = number
        #print(result)
        #htmlcode = result.content.decode('euc-jp')
            
        #if not htmlcode or '<title>404' in htmlcode or 'class="movie-info section"' not in htmlcode:
        #    raise ValueError("page not found")
            
        self.lx = etree.fromstring(htmlcode,etree.HTMLParser())
        self.getVideoInfo(self.lx)
        self.info['source'] = "carib.py"
        self.info['website'] = url
        return self.info



if __name__ == "__main__":
    c = Carib()
    print(c.main("070116-197")) # actor have photo
    # print(c.getMagnetLink(c.lx))
    # print(c.getTitle(c.lx))
    # print(c.getNum(c.lx))     #获取番号
    # print(c.getOutline(c.lx))  #获取剧情介绍 多进程并发查询
    # #print(c.getActorPhoto(c.lx))
    # print(c.getStudioJa(c.lx))
    # print(c.getStudio(c.lx)) #获取厂商
    # print(c.getYear(c.lx))   #获取年份
    # print(c.getCover(c.lx))  #获取封面链接
    # print(c.getRelease(c.lx)) #获取出版日期
    # print(c.getRuntime(c.lx)) #获取分钟 已修改
    # print(c.getActor(c.lx))   #获取女优
    # print(c.getDirectorJa(c.lx))
    # print(c.getDirector(c.lx)) #获取导演
    # print(c.getCID(c.lx))
    # print(c.getSeriesJa(c.lx))
    # print(c.getSeries(c.lx))   #获取系列
    # print(c.getTag(c.lx))  # 获取标签
    # print(c.getExtrafanart(c.lx))  # 获取剧照
    #print(c.main("041721-001"))
    #print(c.main("080520-001"))



from abc import abstractmethod, ABCMeta


class getVideoInfoBase(object):
    __metaclass__ = ABCMeta

    def __init__(self):
        self.info = VideoInfo()

    def getVideoInfo(self,lx):
        self.info['title'] = self.getTitle(lx)
        if self.info['title']:
            self.info['studio'] = self.getStudio(lx)
            self.info['year'] = self.getYear(lx)
            self.info['outline'] = self.getOutline(lx)
            self.info['runtime'] = self.getRuntime(lx)
            self.info['director'] = self.getDirector(lx)
            self.info['actor'] = self.getActor(lx)
            self.info['release'] = self.getRelease(lx)
            self.info['number'] = self.getNum(lx)
            self.info['cover'] = self.getCover(lx)
            self.info['imagecut'] = 1
            self.info['tag'] = self.getTag(lx)
            self.info['extrafanart'] = self.getExtrafanart(lx)
            self.info['label'] = self.getSeries(lx)
            self.info['download'] = self.getMagnetLink(lx)

    @abstractmethod
    def getMagnetLink(self,html):
        pass
    @abstractmethod
    def getActorPhoto(self,html):
        pass
    @abstractmethod
    def getTitle(self,html):  #获取标题
        pass
    @abstractmethod
    def getStudioJa(self,html):
        pass
    @abstractmethod
    def getStudio(self,html): #获取厂商
        pass
    @abstractmethod
    def getYear(self,html):   #获取年份
        pass
    @abstractmethod
    def getCover(self,html):  #获取封面链接
        pass
    @abstractmethod
    def getRelease(self,html): #获取出版日期
        pass
    @abstractmethod
    def getRuntime(self,html): #获取分钟 已修改
        pass
    @abstractmethod
    def getActor(self,html):   #获取女优
        pass
    @abstractmethod
    def getNum(self,html):     #获取番号
        pass
    @abstractmethod
    def getDirectorJa(self,html):
        pass
    @abstractmethod
    def getDirector(self,html): #获取导演
        pass
    @abstractmethod
    def getCID(self,html):
        pass
    @abstractmethod
    def getOutline(self,html):  #获取剧情介绍 多进程并发查询
        pass
    @abstractmethod
    def getSeriesJa(self,html):
        pass
    @abstractmethod
    def getSeries(self,html):   #获取系列
        pass
    @abstractmethod
    def getTag(self,html):  # 获取标签
        pass
    @abstractmethod
    def getExtrafanart(self,html):  # 获取剧照
        pass

class VideoDownloadInfo(dict):
    FIELDS = [
        'title',
        'size',
        'date',
        'isHD',
        'isChn',
        'magnetlink'
    ]

    def __init__(self, *args, **kwargs) -> None:
        super().__init__(*args, **kwargs)
        self['title'] = ''
        self['size'] = ''
        self['date'] = ''
        self['isHD'] = 0
        self['isChn'] = 0
        self['magnetlink'] = ''
        for k, v in kwargs:
            if k in self.FIELDS:
                self[k] = v

    
class VideoInfo(dict):
    FIELDS=[
        'title',
        'studio',
        'year',
        'outline',
        'runtime',
        'director',
        'actor',
        'release',
        'number',
        'cover',
        'imagecut',
        'tag',
        'extrafanart',
        'label',
        #'actor_photo',
        'website',
        'source',
        'series',
        'download'
    ]
    def __init__(self, *args, **kwargs) -> None:
        super().__init__(*args, **kwargs)
        self['title'] = ''
        self['studio'] = ''
        self['year'] = ''
        self['outline'] = ''
        self['runtime'] = ''
        self['director'] = ''
        self['actor'] = ''
        self['release'] = ''
        self['number'] = ''
        self['cover'] = ''
        self['imagecut'] = ''
        self['tag'] = ''
        self['extrafanart'] = ''
        self['label'] = ''
        #self['actor_photo'] = ''
        self['website'] = ''
        self['source'] = ''
        self['series'] = ''
        self['download'] = ''
        for k, v in kwargs:
            if k in self.FIELDS:
                self[k] = v

